#!/usr/bin/env bash

set -euo pipefail

function run-measure-ca {
	local bench_iterations="5"

	local ca_lines="50000"
	local ca_iterations="512"

	local smt="$(cat /sys/devices/system/cpu/smt/active)"

	if [ ! "${smt}" = "0" ]; then
		echo "Hyperthreading / SMT is not disabled! exiting..." 1>&2
		return 1
	fi

	mkdir output/ca
	pushd output/ca

	local timestamp="$(date +%s)"
	echo "OUTPUT DIR: output/ca/${timestamp}"

	mkdir "${timestamp}"
	pushd "${timestamp}"

	local -a programs=(
		"ca-c-gcc"
		"ca-cpp-gcc"
		"ca-fortran-gcc"
		"ca-c-clang"
		"ca-cpp-clang"
		"ca-fortran-llvm-flang"
		"ca-julia"
	)

	for program in "${programs[@]}"; do
		mkdir "${program}"
		pushd "${program}"

		for iteration in $(seq 1 "${bench_iterations}"); do
			mkdir "${iteration}"
			pushd "${iteration}"

			sleep 30

			"$(which time)" -f "%M" -o "memory_usage.txt" \
				ema-measure "${program}" "${ca_lines}" "${ca_iterations}"

			sleep 30

			popd
		done

		popd
	done

	popd
}

if [ "${BASH_SOURCE[0]}" = "${0}" ]; then
	run-measure-ca "$@"
fi
