using tug

# **************
# **** GRID ****
# **************

# create a grid with a 20 x 20 field
row::Int = 40
col::Int = 50
grid::Grid64 = Grid64(row, col)


# (optional) set the domain, e.g.:
# setGridDomain!(grid, 20, 20)

# (optional) set the concentrations, e.g.:
# concentrations::Matrix{Float64} = fill(Float64(1000), (20, 20))
# setGridConcentrations!(grid, concentrations)
concentrations::Matrix{Float64} = zeros(Float64, (col, row))
concentrations[11, 11] = 2000
setGridConcentrations!(grid, concentrations)

# (optional) set alphas of the grid, e.g.:
# alphax::Matrix{Float64} = ones(Float64, (20, 20))
# alphay::Matrix{Float64} = ones(Float64, (20, 20))
# setGridAlpha!(grid, alphax, alphay)

# ******************
# **** BOUNDARY ****
# ******************

# create a boundary with constant values
bc::Boundary{Float64} = Boundary{Float64}(grid)
setBoundarySideClosed!(bc, BC_SIDE_LEFT)
setBoundarySideClosed!(bc, BC_SIDE_RIGHT)
setBoundarySideClosed!(bc, BC_SIDE_TOP)
setBoundarySideClosed!(bc, BC_SIDE_BOTTOM)

# (optional) set boundary condition values for one side, e.g.:
# bc_left_values::Vector{Float64} = ones(Float64, 20)
# setBoundaryConditionValue!(bc, BC_SIDE_LEFT, bc_left_values)
# bc_zero_values::Vector{Float64} = zeros(Float64, 20)
# setBoundaryConditionValue!(bc, BC_SIDE_LEFT, bc_zero_values)
# setBoundaryConditionValue!(bc, BC_SIDE_RIGHT, bc_zero_values)
# bc_front_values::Vector{Float64} = fill(Float64(2000), 20)
# setBoundaryConditionValue!(bc, BC_SIDE_TOP, bc_front_values)
# setBoundaryConditionValue!(bc, BC_SIDE_BOTTOM, bc_zero_values)

# ************************
# **** SIMULATION ENV ****
# ************************

# set up a simulation environment
simulation::Simulation{Float64} = Simulation{Float64}(grid, bc)

# set the timestep of the simulation
setSimulationTimestep!(simulation, 0.1)

# set the number of iterations
setSimulationIterations!(simulation, 300);

# set kind of output [CSV_OUTPUT_OFF (default), CSV_OUTPUT_ON, CSV_OUTPUT_VERBOSE]
setSimulationOutputCSV!(simulation, CSV_OUTPUT_XTREME);

# **** RUN SIMULATION ****

# run the simulation

runSimulation!(simulation)
