// SPDX-License-Identifier: BSD-3-Clause
// SPDX-FileCopyrightText: 2024 Dorian Stoll <dorian.stoll@uni-potsdam.de>

#include <EMA.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/wait.h>
#include <unistd.h>

int main(int argc, char **argv)
{
	int ret = EMA_init(NULL);
	if (ret) {
		(void)fprintf(stderr, "Initializing EMA failed: %d\n", ret);
		return EXIT_FAILURE;
	}

	EMA_REGION_DECLARE(region);
	EMA_REGION_DEFINE(&region, argv[1]);
	EMA_REGION_BEGIN(region);

	pid_t pid = fork();

	if (pid == -1) {
		perror("Creating child process failed");
		return EXIT_FAILURE;
	}

	if (pid == 0)
		execvp(argv[1], &argv[1]);

	ret = waitpid(pid, NULL, 0);
	if (ret == -1) {
		perror("Waiting for child process failed");
		return EXIT_FAILURE;
	}

	EMA_region_end(region);

	ret = EMA_finalize();
	if (ret) {
		(void)fprintf(stderr, "Finalizing EMA failed: %d\n", ret);
		return EXIT_FAILURE;
	}

	return EXIT_SUCCESS;
}
